types

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type EnvVar

type EnvVar struct {
	Text    string
	Key     string
	Value   string
	Mutable bool
}

EnvVar represents a single environement variable for a container.

type PortMapping

type PortMapping struct {
	Text          string
	HostPort      uint16
	ContainerPort uint16
}

PortMapping represents a single port mapping for a container.

type Service

type Service struct {
	Tag          string
	Name         string
	Image        string
	Volumes      []VolumeMount
	PortMappings []PortMapping
	Env          []EnvVar
	InsecureEnv  []EnvVar
	InsecureInfo string
	Command      []string
}

Service describes the properties and methods for a service like MySQL or Redis. All the available services in tent uses this struct as their type.

func (*Service) ApplyInsecure added in v0.1.0

func (s *Service) ApplyInsecure() (string, error)

ApplyInsecure replaces the service's env vars with InsecureEnv for passwordless operation.

func (*Service) ContainerName added in v0.1.0

func (s *Service) ContainerName() string

ContainerName generates unique name for each container by combining their image tag and exposed port number.

func (*Service) ImageName added in v0.1.0

func (s *Service) ImageName() string

ImageName generates full image name for services by combining their image name and tag.

type VolumeMount added in v0.0.4

type VolumeMount struct {
	Text string
	Name string
	Dest string
}

VolumeMount represents a single volume mount for a container.

Jump to