Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PortMapping ¶
PortMapping represents a single port mapping for a container.
type Service ¶
type Service struct {
Tag string
Name string
Image string
Volumes []VolumeMount
PortMappings []PortMapping
Env []EnvVar
InsecureEnv []EnvVar
InsecureInfo string
Command []string
}
Service describes the properties and methods for a service like MySQL or Redis. All the available services in tent uses this struct as their type.
func (*Service) ApplyInsecure ¶ added in v0.1.0
ApplyInsecure replaces the service's env vars with InsecureEnv for passwordless operation.
func (*Service) ContainerName ¶ added in v0.1.0
ContainerName generates unique name for each container by combining their image tag and exposed port number.
type VolumeMount ¶ added in v0.0.4
VolumeMount represents a single volume mount for a container.
Click to show internal directories.
Click to hide internal directories.